@@ -8,6 +8,8 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
+// clazy:excludeall=overloaded-signal
+
 #pragma once
 
 #include "eventview.h"
@@ -28,7 +30,6 @@ namespace Akonadi
 class ETMViewStateSaver;
 }
 
-class QItemSelection;
 class QMenu;
 class QModelIndex;
 class QToolButton;
@@ -53,7 +54,7 @@ class EVENTVIEWS_EXPORT TodoView : public EventViews::EventView
     friend class ModelStack;
 
 public:
-    TodoView(const EventViews::PrefsPtr &preferences, bool sidebarView, QWidget *parent);
+    TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget *parent);
     ~TodoView() override;
 
     void setModel(QAbstractItemModel *model) override;
@@ -114,6 +115,8 @@ protected Q_SLOTS:
     void newTodo();
     void newSubTodo();
     void copyTodoToDate(QDate date);
+    void toggleTodoCompleted();
+    void toggleTodoAlarm();
 
 private Q_SLOTS:
     EVENTVIEWS_NO_EXPORT void scheduleResizeColumns();
@@ -140,7 +143,7 @@ Q_SIGNALS:
     void printPreviewTodo();
     void printTodo();
 
-    void createEvent(const Akonadi::Item &item);
+    void createEvent(const Akonadi::Item &item); // clazy:exclude=overloaded-signal
 
 private:
     EVENTVIEWS_NO_EXPORT QMenu *createCategoryPopupMenu();
